# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetKeyPairsPairResult',
]

@pulumi.output_type
class GetKeyPairsPairResult(dict):
    def __init__(__self__, *,
                 id: str,
                 key_pair_finger_print: str,
                 key_pair_name: str):
        """
        :param str id: The ID of the Key Pair. Its value is same as Queue Name.
        :param str key_pair_finger_print: The Private Key of the Fingerprint.
        :param str key_pair_name: The Key Name.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "key_pair_finger_print", key_pair_finger_print)
        pulumi.set(__self__, "key_pair_name", key_pair_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Key Pair. Its value is same as Queue Name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyPairFingerPrint")
    def key_pair_finger_print(self) -> str:
        """
        The Private Key of the Fingerprint.
        """
        return pulumi.get(self, "key_pair_finger_print")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> str:
        """
        The Key Name.
        """
        return pulumi.get(self, "key_pair_name")


